@@ -14,6 +14,13 @@ class TestBigMath < Test::Unit::TestCase
   MINF = BigDecimal("-Infinity")
   NAN = BigDecimal("NaN")
 
+  def test_no_warning
+    assert_separately([], "#{<<~"begin;"}\n#{<<~'end;'}")
+    begin;
+      require 'bigdecimal/math'
+    end;
+  end
+
   def test_pi
     assert_equal(
       BigDecimal("3.141592653589793238462643383279502884197169399375105820974944592307816406286208998628034825342117068"),
